import unittest

from zope.app.testing.setup import setUpTestAsModule, tearDownTestAsModule
from zope.app.testing.functional import FunctionalDocFileSuite
from z3c.listjs.testing import FunctionalLayer

def setUp(test):
    setUpTestAsModule(test, name='__builtin__')

def test_suite():
    globs = {}
#     readme = FunctionalDocFileSuite(
#         'README.txt',
#         globs = globs,
#         setUp=setUp,
#         tearDown=tearDownTestAsModule,
#         )
    readme.layer = FunctionalLayer
    return unittest.TestSuite([readme])



from setuptools import setup, find_packages
import sys, os

def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

long_description = (
    read('README.txt')
    + '\n' +
    read('CHANGES.txt')
    + '\n' +
    'Download\n'
    '********\n'
    )


setup(
    name='z3c.listjs',
    version='1.0a2',
    description="A formlib list widget that uses Javascript",
    long_description=long_description,
    keywords='zope3 form widget',
    author='Martijn Faassen',
    author_email='faassen@startifact.com',
    license='ZPL 2.1',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Zope Public License',
        'Programming Language :: Python',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Topic :: Internet :: WWW/HTTP',
        'Framework :: Zope3'],
    packages=find_packages('src'),
    package_dir={'': 'src'},
    namespace_packages=['z3c'],
    include_package_data=True,
    zip_safe=False,
    install_requires=[
        'setuptools',
        'zope.schema',
        'zope.app.form',
        'grokcore.component',
        'hurry.resource',
        'hurry.zoperesource >= 0.3',
        ],
    entry_points={},
    )



from zope.app.form.browser import ListSequenceWidget
from zope.app.form.interfaces import IInputWidget
from zope.app.form.browser.widget import renderElement
from zope.app.pagetemplate.viewpagetemplatefile import ViewPageTemplateFile

from zope import component

from hurry.resource import Library, ResourceInclusion

listjs_lib = Library('z3c.listjs')
listjs_js = ResourceInclusion(listjs_lib, 'listjs.js')
listjs_css = ResourceInclusion(listjs_lib, 'listjs.css')

class _ListJsWidget(ListSequenceWidget):

    template = ViewPageTemplateFile('listjswidget.pt')

    def widgetTemplate(self):
        # XXX hack: always get a widget that isn't in the sequence
        sequence = self._getRenderedValue()
        return self._getWidget(len(sequence))()
    
    def __call__(self):
        result = ListSequenceWidget.__call__(self)
        listjs_js.need()
        listjs_css.need()
        return result
    
    def _getPresenceMarker(self, count=0):
        return ('<input type="hidden" id="%s.count" name="%s.count" value="%d" />'
                % (self.name, self.name, count))


def ListJsWidget(field, request):
    return _ListJsWidget(field, field, request)

